openlp-core team mailing list archive
-
openlp-core team
-
Mailing list archive
-
Message #13712
[Merge] lp:~mahfiaz/openlp/bug-904384 into lp:openlp
mahfiaz has proposed merging lp:~mahfiaz/openlp/bug-904384 into lp:openlp.
Requested reviews:
OpenLP Core (openlp-core)
Related bugs:
Bug #904384 in OpenLP: "EasiSlides has been rebranded as EasySlides"
https://bugs.launchpad.net/openlp/+bug/904384
For more details, see:
https://code.launchpad.net/~mahfiaz/openlp/bug-904384/+merge/87199
Rename EasiSlides to EasySlides
--
https://code.launchpad.net/~mahfiaz/openlp/bug-904384/+merge/87199
Your team OpenLP Core is requested to review the proposed merge of lp:~mahfiaz/openlp/bug-904384 into lp:openlp.
=== modified file 'openlp/core/ui/wizard.py'
--- openlp/core/ui/wizard.py 2011-12-27 10:33:55 +0000
+++ openlp/core/ui/wizard.py 2011-12-31 19:02:26 +0000
@@ -47,7 +47,7 @@
CCLI = u'CCLI/SongSelect'
CSV = u'CSV'
EW = u'EasyWorship'
- ES = u'EasiSlides'
+ ES = u'EasySlides'
FP = u'Foilpresenter'
OL = u'OpenLyrics'
OS = u'OpenSong'
=== modified file 'openlp/plugins/songs/forms/songimportform.py'
--- openlp/plugins/songs/lib/importer.py 2011-12-27 10:33:55 +0000
+++ openlp/plugins/songs/lib/importer.py 2011-12-31 19:02:26 +0000
@@ -30,7 +30,7 @@
import logging
from opensongimport import OpenSongImport
-from easislidesimport import EasiSlidesImport
+from easyslidesimport import EasySlidesImport
from olpimport import OpenLPSongImport
from openlyricsimport import OpenLyricsImport
from wowimport import WowImport
@@ -73,7 +73,7 @@
OpenLP1 = 2
Generic = 3
CCLI = 4
- EasiSlides = 5
+ EasySlides = 5
EasyWorship = 6
FoilPresenter = 7
OpenSong = 8
@@ -107,8 +107,8 @@
return OooImport
elif format == SongFormat.CCLI:
return CCLIFileImport
- elif format == SongFormat.EasiSlides:
- return EasiSlidesImport
+ elif format == SongFormat.EasySlides:
+ return EasySlidesImport
elif format == SongFormat.EasyWorship:
return EasyWorshipSongImport
elif format == SongFormat.SongBeamer:
@@ -130,7 +130,7 @@
SongFormat.OpenLP1,
SongFormat.Generic,
SongFormat.CCLI,
- SongFormat.EasiSlides,
+ SongFormat.EasySlides,
SongFormat.EasyWorship,
SongFormat.FoilPresenter,
SongFormat.OpenSong,
Follow ups
--- openlp/plugins/songs/forms/songimportform.py 2011-12-27 10:33:55 +0000
+++ openlp/plugins/songs/forms/songimportform.py 2011-12-31 19:02:26 +0000
@@ -141,9 +141,9 @@
QtCore.QObject.connect(self.genericRemoveButton,
QtCore.SIGNAL(u'clicked()'),
self.onGenericRemoveButtonClicked)
- QtCore.QObject.connect(self.easiSlidesBrowseButton,
+ QtCore.QObject.connect(self.easySlidesBrowseButton,
QtCore.SIGNAL(u'clicked()'),
- self.onEasiSlidesBrowseButtonClicked)
+ self.onEasySlidesBrowseButtonClicked)
QtCore.QObject.connect(self.ewBrowseButton,
QtCore.SIGNAL(u'clicked()'),
self.onEWBrowseButtonClicked)
@@ -201,8 +201,8 @@
self.addFileSelectItem(u'generic', None, True)
# CCLI File import
self.addFileSelectItem(u'ccli')
- # EasiSlides
- self.addFileSelectItem(u'easiSlides', single_select=True)
+ # EasySlides
+ self.addFileSelectItem(u'easySlides', single_select=True)
# EasyWorship
self.addFileSelectItem(u'ew', single_select=True)
# Foilpresenter
@@ -248,7 +248,7 @@
'Generic Document/Presentation'))
self.formatComboBox.setItemText(SongFormat.CCLI, WizardStrings.CCLI)
self.formatComboBox.setItemText(
- SongFormat.EasiSlides, WizardStrings.ES)
+ SongFormat.EasySlides, WizardStrings.ES)
self.formatComboBox.setItemText(
SongFormat.EasyWorship, WizardStrings.EW)
self.formatComboBox.setItemText(
@@ -307,9 +307,9 @@
translate('SongsPlugin.ImportWizardForm', 'The generic document/'
'presentation importer has been disabled because OpenLP cannot '
'access OpenOffice or LibreOffice.'))
- self.easiSlidesFilenameLabel.setText(
+ self.easySlidesFilenameLabel.setText(
translate('SongsPlugin.ImportWizardForm', 'Filename:'))
- self.easiSlidesBrowseButton.setText(UiStrings().Browse)
+ self.easySlidesBrowseButton.setText(UiStrings().Browse)
self.ewFilenameLabel.setText(
translate('SongsPlugin.ImportWizardForm', 'Filename:'))
self.ewBrowseButton.setText(UiStrings().Browse)
@@ -411,11 +411,11 @@
'presentation file to import from.'))
self.genericAddButton.setFocus()
return False
- elif source_format == SongFormat.EasiSlides:
- if self.easiSlidesFilenameEdit.text().isEmpty():
+ elif source_format == SongFormat.EasySlides:
+ if self.easySlidesFilenameEdit.text().isEmpty():
critical_error_message_box(UiStrings().NFSp,
WizardStrings.YouSpecifyFile % WizardStrings.ES)
- self.easiSlidesBrowseButton.setFocus()
+ self.easySlidesBrowseButton.setFocus()
return False
elif source_format == SongFormat.EasyWorship:
if self.ewFilenameEdit.text().isEmpty():
@@ -594,9 +594,9 @@
"""
self.removeSelectedItems(self.genericFileListWidget)
- def onEasiSlidesBrowseButtonClicked(self):
+ def onEasySlidesBrowseButtonClicked(self):
self.getFileName(WizardStrings.OpenTypeFile % WizardStrings.ES,
- self.easiSlidesFilenameEdit)
+ self.easySlidesFilenameEdit)
def onEWBrowseButtonClicked(self):
"""
@@ -673,7 +673,7 @@
self.ccliFileListWidget.clear()
self.songsOfFellowshipFileListWidget.clear()
self.genericFileListWidget.clear()
- self.easiSlidesFilenameEdit.setText(u'')
+ self.easySlidesFilenameEdit.setText(u'')
self.ewFilenameEdit.setText(u'')
self.songBeamerFileListWidget.clear()
self.songShowPlusFileListWidget.clear()
@@ -743,10 +743,10 @@
importer = self.plugin.importSongs(SongFormat.Generic,
filenames=self.getListOfFiles(self.genericFileListWidget)
)
- elif source_format == SongFormat.EasiSlides:
- # Import an EasiSlides export file
- importer = self.plugin.importSongs(SongFormat.EasiSlides,
- filename=unicode(self.easiSlidesFilenameEdit.text())
+ elif source_format == SongFormat.EasySlides:
+ # Import an EasySlides export file
+ importer = self.plugin.importSongs(SongFormat.EasySlides,
+ filename=unicode(self.easySlidesFilenameEdit.text())
)
elif source_format == SongFormat.EasyWorship:
# Import an EasyWorship database
=== renamed file 'openlp/plugins/songs/lib/easislidesimport.py' => 'openlp/plugins/songs/lib/easyslidesimport.py'
--- openlp/plugins/songs/lib/easislidesimport.py 2011-12-27 10:33:55 +0000
+++ openlp/plugins/songs/lib/easyslidesimport.py 2011-12-31 19:02:26 +0000
@@ -35,12 +35,12 @@
log = logging.getLogger(__name__)
-class EasiSlidesImport(SongImport):
+class EasySlidesImport(SongImport):
"""
Import songs exported from EasiSlides
The format example is here:
- http://wiki.openlp.org/Development:EasiSlides_-_Song_Data_Format
+ http://wiki.openlp.org/Development:EasySlides_-_Song_Data_Format
"""
def __init__(self, manager, **kwargs):
"""
@@ -56,7 +56,7 @@
multiple opensong files. If `self.commit` is set False, the
import will not be committed to the database (useful for test scripts).
"""
- log.info(u'Importing EasiSlides XML file %s', self.importSource)
+ log.info(u'Importing EasySlides XML file %s', self.importSource)
parser = etree.XMLParser(remove_blank_text=True)
parsed_file = etree.parse(self.importSource, parser)
xml = unicode(etree.tostring(parsed_file))
@@ -177,7 +177,7 @@
separators = (separatorlines > 0)
# the number of different regions in song - 1
if len(regionlines) > 1:
- log.info(u'EasiSlidesImport: the file contained a song named "%s"'
+ log.info(u'EasySlidesImport: the file contained a song named "%s"'
u'with more than two regions, but only two regions are',
u'tested, encountered regions were: %s',
self.title, u','.join(regionlines.keys()))
@@ -35,12 +35,12 @@
"""
- Import songs exported from EasiSlides
+ Import songs exported from EasySlides
The format example is here:
=== modified file 'openlp/plugins/songs/lib/importer.py'